@@ -19,7 +19,7 @@ namespace Model
   class EnableOrganizationsRootSessionsRequest : public IAMRequest
   {
   public:
-    AWS_IAM_API EnableOrganizationsRootSessionsRequest();
+    AWS_IAM_API EnableOrganizationsRootSessionsRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
